@@ -52,8 +52,10 @@ _PHOTOS_5_MODEL_VERSION = [13000, 13999]
 _PHOTOS_6_MODEL_VERSION = [14000, 14999]
 _PHOTOS_7_MODEL_VERSION = [15000, 15999]  # Dev preview: 15134, 12.1: 15331
 _PHOTOS_8_MODEL_VERSION = [16000, 16999]  # Ventura dev preview: 16119
-_PHOTOS_9_MODEL_VERSION = [17000, 17999]  # Sonoma dev preview: 17120
-_PHOTOS_10_MODEL_VERSION = [18000, 18999]  # Sequoia dev preview: 18164
+_PHOTOS_9_MODEL_VERSION = [17000, 17599]  # Sonoma dev preview: 17120
+_PHOTOS_9_14_6_MODEL_VERSION = [17600, 17999]  # macOS 14.6 changed the schema
+_PHOTOS_10B1_MODEL_VERSION = [18000, 18200]  # Sequoia dev preview 1: 18164
+_PHOTOS_10_MODEL_VERSION = [18201, 18999]
 
 # the preview versions of 12.0.0 had a difference schema for syndication info so need to check model version before processing
 _PHOTOS_SYNDICATION_MODEL_VERSION = 15323  # 12.0.1
@@ -63,7 +65,7 @@ _PHOTOS_SHARED_LIBRARY_VERSION = 16320  # 13.0
 
 # some table names differ between Photos 5 and later versions
 _DB_TABLE_NAMES = {
-    5: {
+    5: {  # macOS 10.15
         "ASSET": "ZGENERICASSET",
         "KEYWORD_JOIN": "Z_1KEYWORDS.Z_37KEYWORDS",
         "ALBUM_JOIN": "Z_26ASSETS.Z_34ASSETS",
@@ -79,7 +81,7 @@ _DB_TABLE_NAMES = {
         "MASTER_FINGERPRINT": "ZADDITIONALASSETATTRIBUTES.ZMASTERFINGERPRINT",
         "HAS_ADJUSTMENTS": "ZGENERICASSET.ZHASADJUSTMENTS",
     },
-    6: {
+    6: {  # macOS 11.0
         "ASSET": "ZASSET",
         "KEYWORD_JOIN": "Z_1KEYWORDS.Z_36KEYWORDS",
         "ALBUM_JOIN": "Z_26ASSETS.Z_3ASSETS",
@@ -95,7 +97,7 @@ _DB_TABLE_NAMES = {
         "MASTER_FINGERPRINT": "ZADDITIONALASSETATTRIBUTES.ZMASTERFINGERPRINT",
         "HAS_ADJUSTMENTS": "ZASSET.ZHASADJUSTMENTS",
     },
-    7: {
+    7: {  # macOS 12.0
         "ASSET": "ZASSET",
         "KEYWORD_JOIN": "Z_1KEYWORDS.Z_38KEYWORDS",
         "ALBUM_JOIN": "Z_27ASSETS.Z_3ASSETS",
@@ -111,7 +113,7 @@ _DB_TABLE_NAMES = {
         "MASTER_FINGERPRINT": "ZADDITIONALASSETATTRIBUTES.ZMASTERFINGERPRINT",
         "HAS_ADJUSTMENTS": "ZASSET.ZHASADJUSTMENTS",
     },
-    8: {
+    8: {  # macOS 13.0
         "ASSET": "ZASSET",
         "KEYWORD_JOIN": "Z_1KEYWORDS.Z_40KEYWORDS",
         "ALBUM_JOIN": "Z_28ASSETS.Z_3ASSETS",
@@ -127,7 +129,7 @@ _DB_TABLE_NAMES = {
         "MASTER_FINGERPRINT": "ZADDITIONALASSETATTRIBUTES.ZMASTERFINGERPRINT",
         "HAS_ADJUSTMENTS": "ZASSET.ZHASADJUSTMENTS",
     },
-    9: {
+    9: {  # macOS 14.0
         "ASSET": "ZASSET",
         "KEYWORD_JOIN": "Z_1KEYWORDS.Z_40KEYWORDS",
         "ALBUM_JOIN": "Z_28ASSETS.Z_3ASSETS",
@@ -143,7 +145,23 @@ _DB_TABLE_NAMES = {
         "MASTER_FINGERPRINT": "ZADDITIONALASSETATTRIBUTES.ZMASTERFINGERPRINT",
         "HAS_ADJUSTMENTS": "ZASSET.ZHASADJUSTMENTS",
     },
-    10: {
+    9.6: {  # macOS 14.6
+        "ASSET": "ZASSET",
+        "KEYWORD_JOIN": "Z_1KEYWORDS.Z_40KEYWORDS",
+        "ALBUM_JOIN": "Z_29ASSETS.Z_3ASSETS",
+        "ALBUM_SORT_ORDER": "Z_29ASSETS.Z_FOK_3ASSETS",
+        "IMPORT_FOK": "null",
+        "DEPTH_STATE": "ZASSET.ZDEPTHTYPE",
+        "UTI_ORIGINAL": "ZINTERNALRESOURCE.ZCOMPACTUTI",
+        "ASSET_ALBUM_JOIN": "Z_29ASSETS.Z_29ALBUMS",
+        "ASSET_ALBUM_TABLE": "Z_29ASSETS",
+        "HDR_TYPE": "ZHDRTYPE",
+        "DETECTED_FACE_PERSON_FK": "ZDETECTEDFACE.ZPERSONFORFACE",
+        "DETECTED_FACE_ASSET_FK": "ZDETECTEDFACE.ZASSETFORFACE",
+        "MASTER_FINGERPRINT": "ZADDITIONALASSETATTRIBUTES.ZMASTERFINGERPRINT",
+        "HAS_ADJUSTMENTS": "ZASSET.ZHASADJUSTMENTS",
+    },
+    9.9: {  # macOS 15.0 beta 1
         "ASSET": "ZASSET",
         "KEYWORD_JOIN": "Z_1KEYWORDS.Z_48KEYWORDS",
         "ALBUM_JOIN": "Z_31ASSETS.Z_3ASSETS",
@@ -159,6 +177,22 @@ _DB_TABLE_NAMES = {
         "MASTER_FINGERPRINT": "ZADDITIONALASSETATTRIBUTES.ZORIGINALSTABLEHASH",
         "HAS_ADJUSTMENTS": "ZASSET.ZADJUSTMENTSSTATE",
     },
+    10: {  # macOS 15
+        "ASSET": "ZASSET",
+        "KEYWORD_JOIN": "Z_1KEYWORDS.Z_48KEYWORDS",
+        "ALBUM_JOIN": "Z_30ASSETS.Z_3ASSETS",
+        "ALBUM_SORT_ORDER": "Z_30ASSETS.Z_FOK_3ASSETS",
+        "IMPORT_FOK": "null",
+        "DEPTH_STATE": "ZASSET.ZDEPTHTYPE",
+        "UTI_ORIGINAL": "ZINTERNALRESOURCE.ZCOMPACTUTI",
+        "ASSET_ALBUM_JOIN": "Z_30ASSETS.Z_30ALBUMS",
+        "ASSET_ALBUM_TABLE": "Z_30ASSETS",
+        "HDR_TYPE": "ZHDRTYPE",
+        "DETECTED_FACE_PERSON_FK": "ZDETECTEDFACE.ZPERSONFORFACE",
+        "DETECTED_FACE_ASSET_FK": "ZDETECTEDFACE.ZASSETFORFACE",
+        "MASTER_FINGERPRINT": "ZADDITIONALASSETATTRIBUTES.ZORIGINALSTABLEHASH",
+        "HAS_ADJUSTMENTS": "ZASSET.ZADJUSTMENTSSTATE",
+    },
 }
 
 # Which version operating systems have been tested
@@ -205,6 +239,8 @@ _TESTED_OS_VERSIONS = [
     ("14", "2"),
     ("14", "3"),
     ("14", "4"),
+    ("14", "5"),
+    ("14", "6"),
 ]
 
 # Photos 5 has persons who are empty string if unidentified face
@@ -394,6 +430,7 @@ class SearchCategory_Photos8(SearchCategory):
     PHOTO_TYPE_SLOMO = 1905
     PHOTO_TYPE_BURSTS = 1913
     PHOTO_TYPE_SCREENSHOT = 1907
+    PHOTO_TYPE_SCREENRECORDINGS = 1916
     PHOTO_TYPE_ANIMATED = 1912
     PHOTO_TYPE_RAW = 1902
     MEDIA_TYPES = [
@@ -401,6 +438,7 @@ class SearchCategory_Photos8(SearchCategory):
         PHOTO_TYPE_SLOMO,
         PHOTO_TYPE_LIVE,
         PHOTO_TYPE_SCREENSHOT,
+        PHOTO_TYPE_SCREENRECORDINGS,
         PHOTO_TYPE_PANORAMA,
         PHOTO_TYPE_TIMELAPSE,
         PHOTO_TYPE_BURSTS,
