@@ -92,6 +92,7 @@ class StagedFiles:
         edited_live: t.Optional[str] = None,
         preview: t.Optional[str] = None,
         raw: t.Optional[str] = None,
+        aae: t.Optional[str] = None,
         error: t.Optional[t.List[str]] = None,
     ):
         self.original = original
@@ -100,6 +101,7 @@ class StagedFiles:
         self.edited_live = edited_live
         self.preview = preview
         self.raw = raw
+        self.aae = aae
         self.error = error or []
 
         # TODO: bursts?
@@ -354,8 +356,23 @@ class PhotoExporter:
                     f"Skipping missing preview photo for {self._filename(self.photo.original_filename)} ({self._uuid(self.photo.uuid)})"
                 )
 
-        if options.export_aae:
-            all_results += self._write_aae_file(dest=dest, options=options)
+        if export_original and self.photo.hasadjustments and options.export_aae:
+            # export associated AAE adjustments file if requested but only for original images
+            # AAE applies changes to the original so is not meaningful for the edited image
+            aae_name = normalize_fs_path(dest.with_suffix(".AAE"))
+            if staged_files.aae:
+                aae_path = pathlib.Path(staged_files.aae)
+                all_results += self._export_aae(
+                    aae_path,
+                    aae_name,
+                    options=options,
+                )
+            else:
+                verbose(
+                    f"Skipping adjustments for {self._filename(self.photo.original_filename)}: no AAE adjustments file"
+                )
+                all_results += ExportResults(missing=[aae_name])
+
         sidecar_writer = SidecarWriter(self.photo)
         all_results += sidecar_writer.write_sidecar_files(dest=dest, options=options)
 
@@ -364,7 +381,8 @@ class PhotoExporter:
         # the history record is written in _export_photo
         # but this isn't called for missing photos
         for filename in all_results.missing:
-            options.export_db.set_history(filename, self.photo.uuid, "missing", None)
+            action = "AAE: missing" if str(filename).endswith(".AAE") else "missing"
+            options.export_db.set_history(filename, self.photo.uuid, action, None)
 
         return all_results
 
@@ -571,12 +589,8 @@ class PhotoExporter:
         staged = StagedFiles()
 
         if options.use_photos_export:
-            # use Photos AppleScript or PhotoKit to do the export
-            return (
-                self._stage_photo_for_export_with_photokit(options=options)
-                if options.use_photokit
-                else self._stage_photo_for_export_with_applescript(options=options)
-            )
+            return self._stage_missing_photos_for_export_helper(
+                options=options)
 
         if options.raw_photo and self.photo.has_raw:
             staged.raw = self.photo.path_raw
@@ -590,6 +604,8 @@ class PhotoExporter:
                 staged.original = self.photo.path
             if options.live_photo and self.photo.live_photo:
                 staged.original_live = self.photo.path_live_photo
+            if options.export_aae:
+                staged.aae = self.photo.adjustments_path
 
         if options.edited:
             # edited file
@@ -629,18 +645,22 @@ class PhotoExporter:
             preview=options.preview and not staged.preview,
             raw_photo=self.photo.has_raw and options.raw_photo and not staged.raw,
             live_photo=self.photo.live_photo and options.live_photo and not live_photo,
+            use_photokit=options.use_photokit,
         )
-        if options.use_photokit:
-            missing_staged = self._stage_photo_for_export_with_photokit(
-                options=missing_options
-            )
-        else:
-            missing_staged = self._stage_photo_for_export_with_applescript(
-                options=missing_options
-            )
+        missing_staged = self._stage_missing_photos_for_export_helper(
+            options=missing_options)
         staged |= missing_staged
         return staged
 
+    def _stage_missing_photos_for_export_helper(
+        self, options: ExportOptions
+    ) -> StagedFiles:
+        """Stage a photo for export with AppleScript or PhotoKit"""
+        if options.use_photokit:
+            return self._stage_photo_for_export_with_photokit(options=options)
+        else:
+            return self._stage_photo_for_export_with_applescript(options=options)
+
     def _stage_photo_for_export_with_photokit(
         self,
         options: ExportOptions,
@@ -1181,12 +1201,13 @@ class PhotoExporter:
             exported_paths.append(str(dest_new))
         return exported_paths
 
-    def _write_aae_file(
+    def _export_aae(
         self,
+        src: pathlib.Path,
         dest: pathlib.Path,
         options: ExportOptions,
     ) -> ExportResults:
-        """Write AAE file for the photo."""
+        """Export AAE file for the photo."""
 
         # AAE files describe adjustments to originals, so they don't make sense
         # for edited files
@@ -1195,42 +1216,89 @@ class PhotoExporter:
 
         verbose = options.verbose or self._verbose
 
-        aae_src = self.photo.adjustments_path
-        if aae_src is None:
-            verbose(
-                f"Skipping adjustments for {self._filename(self.photo.original_filename)}: no AAE adjustments file"
-            )
-            return ExportResults()
-        aae_dest = normalize_fs_path(dest.with_suffix(".AAE"))
+        action = None
+
+        if options.update or options.force_update:  # updating
+            if dest.exists():
+                if update_reason := self._should_update_photo(src, dest, options):
+                    action = "update: " + update_reason.name
+                else:
+                    # update_skipped_files.append(dest_str)
+                    action = "skip"
+            else:
+                action = "new"
+        else:
+            action = "export"
+
+        if action == "skip":
+            if dest.exists():
+                options.export_db.set_history(
+                    filename=str(dest), uuid=self.photo.uuid, action=f"AAE: {action}", diff=None
+                )
+                return ExportResults(aae_skipped=[str(dest)], skipped=[str(dest)])
+            else:
+                action = "export"
+
+        errors = []
+        if dest.exists() and any(
+            [options.overwrite, options.update, options.force_update]
+        ):
+            try:
+                options.fileutil.unlink(dest)
+            except Exception as e:
+                errors.append(f"Error removing file {dest}: {e} (({lineno(__file__)})")
 
         if options.export_as_hardlink:
             try:
-                if aae_dest.exists() and any(
-                    [options.overwrite, options.update, options.force_update]
-                ):
-                    try:
-                        options.fileutil.unlink(aae_dest)
-                    except Exception as e:
-                        raise ExportError(
-                            f"Error removing file {aae_dest}: {e} (({lineno(__file__)})"
-                        ) from e
-                options.fileutil.hardlink(aae_src, aae_dest)
+                options.fileutil.hardlink(src, dest)
             except Exception as e:
-                raise ExportError(
-                    f"Error hardlinking {aae_src} to {aae_dest}: {e} ({lineno(__file__)})"
-                ) from e
+                errors.append(
+                    f"Error hardlinking {src} to {dest}: {e} ({lineno(__file__)})"
+                )
         else:
             try:
-                options.fileutil.copy(aae_src, aae_dest)
+                options.fileutil.copy(src, dest)
             except Exception as e:
-                raise ExportError(
-                    f"Error copying file {aae_src} to {aae_dest}: {e} ({lineno(__file__)})"
-                ) from e
+                errors.append(
+                    f"Error copying file {src} to {dest}: {e} ({lineno(__file__)})"
+                )
+
+        # set data in the database
+        fileutil = options.fileutil
+        with options.export_db.create_or_get_file_record(
+            str(dest), self.photo.uuid
+        ) as rec:
+            # don't set src_sig as that is set above before any modifications by convert_to_jpeg or exiftool
+            rec.src_sig = fileutil.file_sig(src)
+            if not options.ignore_signature:
+                rec.dest_sig = fileutil.file_sig(dest)
+            rec.export_options = options.bit_flags
+            if errors:
+                rec.error = {
+                    "error": errors,
+                    "exiftool_error": None,
+                    "exiftool_warning": None,
+                }
+
+        options.export_db.set_history(
+            filename=str(dest), uuid=self.photo.uuid, action=f"AAE: {action}", diff=None
+        )
 
         verbose(
-            f"Exported adjustments of {self._filename(self.photo.original_filename)} to {self._filepath(aae_dest)}"
+            f"Exported adjustments for {self._filename(self.photo.original_filename)} to {self._filepath(dest)}"
+        )
+
+        written = [str(dest)]
+        exported = written if action in {"export", "new"} else []
+        new = written if action == "new" else []
+        updated = written if "update" in action else []
+        return ExportResults(
+            aae_written=written,
+            exported=exported,
+            new=new,
+            updated=updated,
+            error=errors,
         )
-        return ExportResults(aae_written=[aae_dest])
 
     def write_exiftool_metadata_to_file(
         self,
