@@ -350,6 +350,11 @@ class PhotoAsset:
         """return True if asset is screenshot, otherwise False"""
         return bool(self.media_subtypes & Photos.PHAssetMediaSubtypePhotoScreenshot)
 
+    @property
+    def screen_recording(self):
+        """return True if asset is screen recordings, otherwise False"""
+        return bool(self.media_subtypes & Photos.PHAssetMediaSubtypePhotoScreenRecording)
+
     @property
     def live(self):
         """return True if asset is live, otherwise False"""
