@@ -6,12 +6,14 @@ import datetime
 import json
 import os
 import pathlib
-import time
 from typing import Any
 
 import pytest
+from click.testing import CliRunner
 
 from osxphotos import QueryOptions, iPhotoDB
+from osxphotos.cli.export import export
+from osxphotos.exiftool import get_exiftool_path
 from osxphotos.iphoto import iPhotoPhotoInfo, is_iphoto_library
 
 IPHOTO_LIBRARY = "tests/Test-iPhoto-9.6.1.photolibrary"
@@ -23,6 +25,12 @@ ALBUM_TITLES = ["Test Album", "Pumpkin Farm", "Last Import", "AlbumInFolder"]
 # Then replace the path to the library with `IPHOTO_LIBRARY_ROOT`
 TEST_DATA = "tests/iphoto_test_data.json"
 
+# determine if exiftool installed so exiftool tests can be skipped
+try:
+    exiftool = get_exiftool_path()
+except:
+    exiftool = None
+
 
 def recursive_str_replace(
     dict_data: dict[Any, Any], old: str, new: str
@@ -184,3 +192,34 @@ def test_iphoto_info(iphotodb: iPhotoDB, photo_dict: dict[str, Any]):
         if key != "fingerprint":
             # fingerprint not implemented on linux
             assert value == photo_dict[key]
+
+
+@pytest.mark.skipif(exiftool is None, reason="exiftool not installed")
+def test_iphoto_export_fix_orientation():
+    """Test export with --fix-orientation flag"""
+    runner = CliRunner()
+    cwd = os.getcwd()
+    with runner.isolated_filesystem():
+        result = runner.invoke(
+            export,
+            [
+                ".",
+                "--fix-orientation",
+                "--library",
+                f"{cwd}/{IPHOTO_LIBRARY}",
+                "--verbose",
+            ],
+        )
+        assert result.exit_code == 0
+        assert (
+            "File orientation not set for photo RgISIEPbThGVoco5LyiLjQ but photo orientation is 1 (normal), no fix needed"
+            in result.output
+        )
+        assert (
+            "File orientation None does not match photo.orientation 8 for photo E5FQ%pg4SRyKPi4dk6rUrg, fixing orientation"
+            in result.output
+        )
+        assert (
+            "Orientation matches for photo UaL9+WGLTRSpqLbgUoUsIQ, no fix needed"
+            in result.output
+        )
